============
Installation
============

At the command line::

    $ easy_install moma-django

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv moma-django
    $ pip install moma-django